==> haskell-crypto-pubkey-0.2.8-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey
version:              0.2.8
visibility:           public
id:                   crypto-pubkey-0.2.8-Ba9p06iVAA789ygj6YZumj
key:                  crypto-pubkey-0.2.8-Ba9p06iVAA789ygj6YZumj
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-crypto-pubkey
synopsis:             Public Key cryptography
description:
    Public Key cryptography

    Supports RSA PKCS15, RSA OAEP, RSA PSS, DSA, ElGamal signature.

    Also have primitive support for Diffie Hellman, and ElGamal encryption

category:             Cryptography
abi:                  61770a669fdb3c7d5d4c9dc19a696d10
exposed:              True
exposed-modules:
    Crypto.PubKey.DH Crypto.PubKey.DSA Crypto.PubKey.ECC.DH
    Crypto.PubKey.ECC.ECDSA Crypto.PubKey.ECC.Generate
    Crypto.PubKey.ECC.Prim Crypto.PubKey.HashDescr
    Crypto.PubKey.MaskGenFunction Crypto.PubKey.RSA
    Crypto.PubKey.RSA.OAEP Crypto.PubKey.RSA.PKCS15
    Crypto.PubKey.RSA.PSS Crypto.PubKey.RSA.Prim

hidden-modules:
    Crypto.PubKey.ElGamal Crypto.PubKey.RSA.Types
    Crypto.PubKey.Internal

import-dirs:          /usr/lib/ghc-8.10.2/site-local/crypto-pubkey-0.2.8
library-dirs:         /usr/lib/ghc-8.10.2/site-local/crypto-pubkey-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/crypto-pubkey-0.2.8
hs-libraries:         HScrypto-pubkey-0.2.8-Ba9p06iVAA789ygj6YZumj
depends:
    base-4.14.1.0 byteable-0.1.1-FeSdIMqUIcwI3U3IhpOBJ3
    bytestring-0.10.10.0 crypto-numbers-0.2.7-7boJrAMlTM35HI26hwSvW2
    crypto-pubkey-types-0.4.3-Cnx0qpP2kbBIRJuzrJMeMy
    crypto-random-0.0.9-CGsiGoFU8HidMWbyBIic9
    cryptohash-0.11.9-Ah2lmvC5w5L7DPL0FWRNIZ

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey/html/crypto-pubkey.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-0.2.8-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey
version:              0.2.8
visibility:           public
id:                   crypto-pubkey-0.2.8-DiSA4ZHYlxyGUnHFLrxINN
key:                  crypto-pubkey-0.2.8-DiSA4ZHYlxyGUnHFLrxINN
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-crypto-pubkey
synopsis:             Public Key cryptography
description:
    Public Key cryptography

    Supports RSA PKCS15, RSA OAEP, RSA PSS, DSA, ElGamal signature.

    Also have primitive support for Diffie Hellman, and ElGamal encryption

category:             Cryptography
abi:                  c86c1dabe64cda653850dc487ece5eab
exposed:              True
exposed-modules:
    Crypto.PubKey.DH Crypto.PubKey.DSA Crypto.PubKey.ECC.DH
    Crypto.PubKey.ECC.ECDSA Crypto.PubKey.ECC.Generate
    Crypto.PubKey.ECC.Prim Crypto.PubKey.HashDescr
    Crypto.PubKey.MaskGenFunction Crypto.PubKey.RSA
    Crypto.PubKey.RSA.OAEP Crypto.PubKey.RSA.PKCS15
    Crypto.PubKey.RSA.PSS Crypto.PubKey.RSA.Prim

hidden-modules:
    Crypto.PubKey.ElGamal Crypto.PubKey.RSA.Types
    Crypto.PubKey.Internal

import-dirs:          /usr/lib/ghc-8.10.2/site-local/crypto-pubkey-0.2.8
library-dirs:         /usr/lib/ghc-8.10.2/site-local/crypto-pubkey-0.2.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/crypto-pubkey-0.2.8
hs-libraries:         HScrypto-pubkey-0.2.8-DiSA4ZHYlxyGUnHFLrxINN
depends:
    base-4.14.1.0 byteable-0.1.1-FeSdIMqUIcwI3U3IhpOBJ3
    bytestring-0.10.10.0 crypto-numbers-0.2.7-I19gOwAGha0EicMNVjby3
    crypto-pubkey-types-0.4.3-C0vqABdDcfZGVEHiqMm3gT
    crypto-random-0.0.9-I9CYmoSKPwh7axGuXqTU9E
    cryptohash-0.11.9-Ah2lmvC5w5L7DPL0FWRNIZ

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey/html/crypto-pubkey.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
